# Gauge Python   [![Build Status](https://snap-ci.com/kashishm/gauge-python/branch/master/build_image)](https://snap-ci.com/kashishm/gauge-python/branch/pyhton2)
Python language runner for [Gauge](https://github.com/getgauge/gauge)

###Documentation

* [User](https://github.com/kashishm/gauge-python/wiki/User-Documentation)
* [Technical](https://github.com/kashishm/gauge-python/wiki/Technical-Documentation)

### How can I contribute

Contributions can be of many forms:

- Open an issue, or participate in an existing one.
- Write some code, and send us a pull request.
- Enhance the documentation

### License

The Gauge-Python is an open-sourced software licensed under the [MIT license](http://opensource.org/licenses/MIT).
